/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#include "config.h"

#include <qpushbt.h>
#include <qlabel.h>
#include <qvalidator.h>
#include <ctype.h>

#include "kreptoned.h"
#include "newepisodedialog.h"

class EpisodeValidator : public QValidator {
public:
	EpisodeValidator(QWidget *parent = 0, const char *name = 0);

	State validate(QString& input, int& pos);
};

EpisodeValidator::EpisodeValidator(QWidget *parent, const char *name)
	: QValidator(parent, name)
{
}

EpisodeValidator::State EpisodeValidator::validate(QString& input, int&)
{
	if (input == "")
		return Valid;

	const char *s;
	for (s = input; *s != '\0'; ++s) 
		if (!isalnum(*s))
			return Invalid;

	return Acceptable;
}

NewEpisodeDialog::NewEpisodeDialog(QWidget *parent, const char *name)
	: QDialog(parent, name, true)
{
	setCaption("New Episode");

	episode_name = new QLineEdit(this);
	episode_name->setGeometry(120, 10, 100, 30);
	QLabel *label = new QLabel(episode_name, "Episode &name", this);
	label->setAutoResize(true);
	label->move(10, 15);

	episode_filename = new QLineEdit(this);
	episode_filename->setGeometry(120, 50, 100, 30);
	EpisodeValidator *validator = new EpisodeValidator(this);
	episode_filename->setValidator(validator);
	label = new QLabel(episode_filename, "Episode &filename", this);
	label->setAutoResize(true);
	label->move(10, 55);

	copy_combo = new QComboBox(this);
	copy_combo->setGeometry(120, 90, 100, 30);

	QList<Episode> l;
	loadEpisodeList(l, true);
	loadEpisodeList(l, false);
	for (Episode *e = l.first(); e != 0; e = l.next())
		copy_combo->insertItem(e->name);
	label = new QLabel(copy_combo, "Use as &template", this);
	label->setAutoResize(true);
	label->move(10, 95);

	ok_button = new QPushButton("OK", this);
	ok_button->setGeometry(10, 140, 70, 30);
	ok_button->setDefault(true);
	cancel_button = new QPushButton("Cancel", this);
	cancel_button->setGeometry(90, 140, 70, 30);

	connect(ok_button, SIGNAL(clicked()),
		this, SLOT(accept()));
	connect(cancel_button, SIGNAL(clicked()),
		this, SLOT(reject()));

	episode_name->setFocus();
}
